@@ -49,6 +49,7 @@ OC.L10N.register(
     "Search" : "Chwilio",
     "Send" : "Anfon",
     "Refresh" : "Ail-lwytho",
+    "Ok" : "Iawn",
     "Subject" : "Pwnc",
     "Saving draft …" : "Yn cadw drafft …",
     "Draft saved" : "Cadwyd y drafft",
@@ -60,9 +61,10 @@ OC.L10N.register(
     "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
     "Favorite" : "Ffefryn",
     "Back" : "Nôl",
-    "Create event" : "Creu digwyddiad",
     "Report this bug" : "Cofnodi'r gwall",
+    "Create event" : "Creu digwyddiad",
     "All day" : "Drwy'r dydd",
+    "Attendees" : "Mynychwyr",
     "Description" : "Disgrifiad",
     "Create" : "Creu",
     "Select" : "Select",
@@ -70,6 +72,7 @@ OC.L10N.register(
     "Accept" : "Derbyn",
     "Decline" : "Gwrthod",
     "Remove" : "Gwaredu",
+    "Today" : "Heddiw",
     "Other" : "Arall",
     "Translate" : "Cyfieithu",
     "Choose a folder to store the attachment in" : "Dewiswch ffolder i gadw'r atodiad ynddi",
@@ -83,6 +86,7 @@ OC.L10N.register(
     "Remove account" : "Dileu cyfrif",
     "Add folder" : "Ychwanegu ffolder",
     "Show all folders" : "Dangos pob ffolder",
+    "Collapse folders" : "Cwympo ffolderi",
     "Loading …" : "Yn llwytho …",
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
     "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
@@ -102,6 +106,8 @@ OC.L10N.register(
     "Recipient" : "Derbynnydd",
     "User" : "Defnyddwyr",
     "Certificate" : "Tystysgrif",
+    "Group" : "Grŵp",
+    "Shared" : "Rhannwyd",
     "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
@@ -124,8 +130,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
-    "Continue to %s" : "Parhau i %s",
-    "Draft: " : "Drafft:",
-    "Actions" : "Gweithredoedd"
+    "Continue to %s" : "Parhau i %s"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
