@@ -60,6 +60,7 @@ OC.L10N.register(
     "More actions" : "Más acciones",
     "Back" : "Atrás",
     "All day" : "Todo el día",
+    "Attendees" : "Asistentes",
     "Description" : "Descripción",
     "Create" : "Crear",
     "Select" : "Seleccionar",
@@ -135,7 +136,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s",
-    "Actions" : "Acciones"
+    "Continue to %s" : "Continuar a %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
