@@ -153,10 +153,10 @@ OC.L10N.register(
     "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Halda S/MIME sertifikaate",
     "Mailvelope" : "Mailvelope",
-    "Mailvelope is enabled for the current domain!" : "Mailvelope on selle domeeni puhul kasutusel!",
-    "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
-    "Install Mailvelope browser extension" : "Paigalda Mailvelope'i brauserilaiendus",
-    "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!",
+    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope on brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
+    "Mailvelope is enabled for the current domain." : "Mailvelope on selle domeeni puhul kasutusel.",
+    "Step 1: Install Mailvelope browser extension" : "1. samm: Paigalda Mailvelope'i brauserilaiendus",
+    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele",
     "Assistance features" : "Abilise funktsionaalsused",
     "About" : "Rakenduse teave",
     "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
@@ -360,8 +360,11 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
+    "Load more follow ups" : "Laadi veel jätkukirju",
     "Important info" : "Oluline teave",
+    "Load more important messages" : "Laadi veel olulisi kirju",
     "Other" : "Muu",
+    "Load more other messages" : "Laadi veel muid kirju",
     "The sender of this message has asked to be notified when you read this message." : "Selle kirja saatja on palunud kinnitust, kui oled kirja lugenud.",
     "Notify the sender" : "Teavita saatjat",
     "You sent a read confirmation to the sender of this message." : "Sa saatsid selle kirja saatjale lugemisteatise.",
@@ -796,6 +799,10 @@ OC.L10N.register(
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
-    "Continue to %s" : "Jätka siia: %s"
+    "Continue to %s" : "Jätka siia: %s",
+    "Mailvelope is enabled for the current domain!" : "Mailvelope on selle domeeni puhul kasutusel!",
+    "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
+    "Install Mailvelope browser extension" : "Paigalda Mailvelope'i brauserilaiendus",
+    "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!"
 },
 "nplurals=2; plural=(n != 1);");
