@@ -28,12 +28,14 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Favorite" : "Favorite",
     "Back" : "Retro",
+    "Attendees" : "Participantes",
     "Description" : "Description",
     "Create" : "Crear",
     "Select" : "Selectionar",
     "Comment" : "Commentario",
     "Accept" : "Acceptar",
     "Decline" : "Refusar",
+    "Today" : "Hodie",
     "Other" : "Altere",
     "Unnamed" : "Non nominate",
     "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
@@ -57,11 +59,13 @@ OC.L10N.register(
     "Host" : "Hospite",
     "Port" : "Porto",
     "Valid until" : "Valide usque",
+    "Group" : "Gruppo",
+    "Shared" : "Compartite",
+    "Shares" : "Compartimentos",
     "All" : "Tote",
     "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
     "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}",
-    "Actions" : "Actiones"
+    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
 },
 "nplurals=2; plural=(n != 1);");
