@@ -101,22 +101,29 @@ OC.L10N.register(
     "Accounts" : "계정",
     "Add mail account" : "메일 계정 추가",
     "General" : "일반",
+    "Layout" : "레이아웃",
+    "List" : "목록",
+    "Vertical split" : "수직 분할",
+    "Horizontal split" : "수평 분할",
     "Sorting" : "정렬",
     "Newest" : "최신순",
     "Oldest" : "과거순",
+    "Search in body" : "본문 검색",
     "Reply text position" : "답장 문구 위치",
     "Gravatar settings" : "Gravatar 설정",
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
     "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
     "Register" : "등록",
+    "Text blocks" : "텍스트 블록",
+    "Create a new text block" : "새로운 텍스트 블록 생성",
+    "Privacy and security" : "개인정보 및 보안",
     "Data collection consent" : "데이터 수집 동의",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
     "Trusted senders" : "신뢰할 수 있는 발신자",
+    "Internal addresses" : "내부 주소",
     "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "S/MIME 인증서 관리",
     "Mailvelope" : "Mailvelope",
-    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
-    "Install Mailvelope browser extension" : "Mailvelope 브라우저 확장 설치",
     "Keyboard shortcuts" : "키보드 단축키",
     "Compose new message" : "새 메시지 작성",
     "Newer message" : "새로운 메시지",
@@ -128,6 +135,9 @@ OC.L10N.register(
     "Search" : "검색",
     "Send" : "보내기",
     "Refresh" : "새로 고침",
+    "New text block" : "새로운 텍스트 블록",
+    "Title of the text block" : "텍스트 블록의 제목",
+    "Content of the text block" : "텍스트 블록의 내용",
     "Ok" : "확인",
     "No certificate" : "인증서 없음",
     "Certificate updated" : "인증서 갱신됨",
@@ -280,7 +290,8 @@ OC.L10N.register(
     "email" : "이메일",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "이 메시지를 보관 폴더로 옮기거나 현재 폴더에서 삭제할 수 없습니다",
     "Today" : "오늘",
-    "Last week" : "저번 주",
+    "Yesterday" : "어제",
+    "Last week" : "지난 주",
     "Loading messages …" : "메시지를 불러오는 중 ...",
     "Choose target folder" : "폴더 선택",
     "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
@@ -316,10 +327,10 @@ OC.L10N.register(
     "_View {count} more attachment_::_View {count} more attachments_" : ["{count}개의 첨부파일 더 보기"],
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "이 메시지는 PGP로 암호화되었습니다. Mailvelope를 설치하여 해제하십시오",
     "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
-    "Show images" : "사진 보이기",
+    "Show images" : "이미지 보기",
     "Show images temporarily" : "임시로 이미지 보기",
     "Always show images from {sender}" : "{sender}이(가) 보낸 이미지를 항상 보기",
-    "Always show images from {domain}" : "{domail}(으)로부터 발신된 이미지를 항상 보기",
+    "Always show images from {domain}" : "{domain}(으)로부터 발신된 이미지를 항상 보기",
     "Quoted text" : "인용된 문구",
     "Move" : "이동",
     "Moving" : "이동 중",
@@ -372,6 +383,7 @@ OC.L10N.register(
     "Retry" : "다시 시도",
     "Warning sending your message" : "메시지 전송 경고",
     "Send anyway" : "무시하고 보내기",
+    "Start writing a message by clicking below or select an existing message to display its contents" : "아래 버튼을 눌러 새로운 메시지를 작성하거나 기존 메시지를 선택하여 내용을 확인하세요",
     "Autoresponder off" : "자동 응답 끄기",
     "Autoresponder on" : "자동 응답 켜기",
     "Autoresponder follows system settings" : "자동 응답은 시스템 설정을 따릅니다",
@@ -397,6 +409,7 @@ OC.L10N.register(
     "Show less" : "적게 보기",
     "Show more" : "더 보기",
     "Clear" : "비우기",
+    "Search in folder" : "폴더에서 검색",
     "Close" : "닫기",
     "Search parameters" : "검색 인자",
     "Search subject" : "제목 검색",
@@ -596,9 +609,18 @@ OC.L10N.register(
     "Private key (optional)" : "개인 키 (선택사항)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "개인 키는 이 인증서를 사용하여 서명하거나 암호화한 이메일을 보낼 때만 사용됩니다",
     "Submit" : "제출",
+    "No text blocks available" : "텍스트 블록이 없습니다",
+    "Text block deleted" : "텍스트 블록 삭제됨",
+    "Failed to delete text block" : "텍스트 블록을 삭제하지 못했습니다",
+    "Text block shared with {sharee}" : "{sharee}와(과) 텍스트 블록 공유함",
+    "Failed to share text block with {sharee}" : "텍스트 블록을 {sharee}와(과) 공유하지 못했습니다",
+    "Failed to save text block" : "텍스트 블록을 저장하지 못했습니다",
     "Shared" : "공유됨",
+    "Edit text block" : "텍스트 블록 수정",
     "Shares" : "공유",
+    "Choose a text block to insert at the cursor" : "커서에 삽입할 텍스트 블록을 선택하세요",
     "Insert" : "삽입",
+    "Insert text block" : "텍스트 블록 삽입",
     "Account connected" : "계정 연결됨",
     "You can close this window" : "윈도우를 닫으셔도 됩니다",
     "Connect your mail account" : "메일 계정에 연결",
@@ -636,6 +658,10 @@ OC.L10N.register(
     "Redirect" : "넘겨주기",
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
-    "Continue to %s" : "%s(으)로 이동"
+    "Continue to %s" : "%s(으)로 이동",
+    "Mailvelope is enabled for the current domain!" : "Mailvelope이 현재 도메인에 대해 활성화되어 있습니다!",
+    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
+    "Install Mailvelope browser extension" : "Mailvelope 브라우저 확장 설치",
+    "Enable Mailvelope for the current domain" : "현재 도메인에 Mailvelope 활성화하기"
 },
 "nplurals=1; plural=0;");
