@@ -94,7 +94,6 @@ OC.L10N.register(
     "Internal addresses" : "Vidiniai adresai",
     "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
-    "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
     "About" : "Apie",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Compose new message" : "Rašyti naują laišką",
@@ -444,6 +443,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
-    "Continue to %s" : "Tęsti į %s"
+    "Continue to %s" : "Tęsti į %s",
+    "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
