@@ -57,7 +57,7 @@ OC.L10N.register(
     "Refresh" : "Atsvaidzināt",
     "Ok" : "Labi",
     "From" : "No",
-    "Select account" : "Izvēlieties kontu",
+    "Select account" : "Atlasīt kontu",
     "To" : "Līdz",
     "Subject" : "Temats",
     "Write message …" : "Rakstiet ziņu...",
@@ -94,7 +94,7 @@ OC.L10N.register(
     "Translate" : "Tulkot",
     "View source" : "Skatīt avotu",
     "Unnamed" : "Nenosaukts",
-    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
+    "Choose a folder to store the attachment in" : "Jāizvēlas mape, kurā saglabāt pielikumu",
     "Import into calendar" : "Ievietot kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
