@@ -31,6 +31,7 @@ OC.L10N.register(
     "Search" : "Хайх",
     "Send" : "илгээх",
     "Refresh" : "Сэргээх",
+    "Ok" : "За",
     "Select account" : "Аккаунт сонгох",
     "Subject" : "Сэдэв",
     "Add attachment from Files" : "Файлаас хавсралт нэмэх",
@@ -38,6 +39,7 @@ OC.L10N.register(
     "Confirm" : "Батлах",
     "Favorite" : "Дуртай",
     "Back" : "буцах",
+    "Attendees" : "Оролцогчид",
     "Description" : "Тодорхойлолт",
     "Create" : "Үүсгэх",
     "Select" : "Сонгох",
@@ -46,6 +48,8 @@ OC.L10N.register(
     "Decline" : "Зөвшөөрөхгүй",
     "Remove" : "Устгах",
     "email" : "цахим шуудан",
+    "Today" : "өнөөдөр",
+    "Yesterday" : "Өчигдөр",
     "Choose target folder" : "Зорилтот хавтасыг сонгох",
     "Other" : "Бусад",
     "Forward" : "дамжих",
@@ -77,6 +81,8 @@ OC.L10N.register(
     "Port" : "порт",
     "Certificate" : "Гэрчилгээ",
     "Submit" : "мэдэгдэх",
+    "Shared" : "Түгээсэн",
+    "Shares" : "Түгээлтүүд",
     "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
     "All" : "бүх",
     "Drafts" : "ноорог",
@@ -85,7 +91,6 @@ OC.L10N.register(
     "Junk" : "хэрэггүй",
     "Sent" : "илгээсэн",
     "Trash" : "хог",
-    "Error loading message" : "алдаатай ачааллах зурвас",
-    "Actions" : "Үйл ажиллагаа"
+    "Error loading message" : "алдаатай ачааллах зурвас"
 },
 "nplurals=2; plural=(n != 1);");
