@@ -43,6 +43,7 @@ OC.L10N.register(
     "Search" : "Kërko",
     "Send" : "Dërgo",
     "Refresh" : "Rifresko",
+    "Ok" : "Në rregull",
     "Select account" : "Përzgjidhni llogari",
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
@@ -56,7 +57,10 @@ OC.L10N.register(
     "Edit tags" : "Përpunoni etiketa",
     "More actions" : "Më tepër veprime ",
     "Back" : "Prapa",
+    "Mark as unread" : "Shënoje si të palexuar",
+    "Mark as read" : "Shënoje si të lexuar",
     "All day" : "Gjithë ditën",
+    "Attendees" : "Pjesëmarrës",
     "Description" : "Përshkrim",
     "Create" : "Krijo",
     "Select" : "Zgjidhni",
@@ -65,6 +69,7 @@ OC.L10N.register(
     "Decline" : "Refuzo",
     "Remove" : "Hiq",
     "email" : "postë elektronike",
+    "Today" : "Sot",
     "Other" : "Tjetër",
     "Forward" : "Përpara",
     "Translate" : "Përkthe",
@@ -100,8 +105,6 @@ OC.L10N.register(
     "Delete tag" : "Fshi etiketën",
     "Tag already exists" : "Etiketa ekziston",
     "Add tag" : "Shto etiketim",
-    "Mark as unread" : "Shënoje si të palexuar",
-    "Mark as read" : "Shënoje si të lexuar",
     "Recipient" : "Marrës",
     "matches" : "përputhje",
     "Priority" : "Përparësi",
@@ -114,6 +117,9 @@ OC.L10N.register(
     "Valid until" : "E vlefshme deri më",
     "Certificate" : "Çertifikata",
     "Submit" : "Dërgo",
+    "Group" : "Grup",
+    "Shared" : "Ndarë",
+    "Shares" : "Shpërndarje",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
@@ -132,7 +138,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "Continue to %s" : "Vazhdo te %s",
-    "Actions" : "Veprimet"
+    "Continue to %s" : "Vazhdo te %s"
 },
 "nplurals=2; plural=(n != 1);");
