@@ -79,8 +79,6 @@ OC.L10N.register(
     "Register" : "Registrera",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
     "Trusted senders" : "Betrodda avsändare",
-    "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
-    "Install Mailvelope browser extension" : "Installera webbläsartillägget Mailvelope",
     "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
@@ -385,6 +383,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s"
+    "Continue to %s" : "Fortsätt till %s",
+    "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
+    "Install Mailvelope browser extension" : "Installera webbläsartillägget Mailvelope"
 },
 "nplurals=2; plural=(n != 1);");
