@@ -22,6 +22,7 @@ OC.L10N.register(
     "Search" : "Qidirish",
     "Send" : "Send",
     "Refresh" : "Refresh",
+    "Ok" : "Yaxshi",
     "From" : "Dan",
     "To" : "Gacha",
     "Choose" : "Choose",
@@ -34,6 +35,7 @@ OC.L10N.register(
     "Back" : "Orqaga",
     "Create event" : "Tadbir yaratish",
     "All day" : "Butun kun",
+    "Attendees" : "Ishtirokchilar",
     "Description" : "Tavsif",
     "Create" : "Yaratish",
     "Select" : "Select",
@@ -43,6 +45,10 @@ OC.L10N.register(
     "More options" : "Boshqa variantlar",
     "Remove" : "O'chirish",
     "email" : "email",
+    "Today" : "Bugun",
+    "Yesterday" : "Kecha",
+    "Last week" : "O`tgan yil",
+    "Last month" : "Oxirgi oy",
     "Other" : "Boshqa",
     "Translate" : "Tarjima",
     "Move" : "Move",
@@ -68,11 +74,11 @@ OC.L10N.register(
     "Reset" : "Qayta tiklash",
     "Client ID" : "Mijoz identifikatori",
     "Port" : "Port",
+    "Shared" : "Ulashilgan",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
     "Favorites" : "Favorites",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
-    "Continue to %s" : " %sni davom eting",
-    "Actions" : "Faolliklar"
+    "Continue to %s" : " %sni davom eting"
 },
 "nplurals=1; plural=0;");
